@@ -67,7 +67,6 @@
 #include <sys/wait.h>
 #include <fcntl.h>
 #include <errno.h>
-#include <kdemacros.h>
 
 #include <qcolor.h>
 #include <qfile.h>
@@ -82,7 +81,7 @@
 
 extern "C"
 {
-    KDE_EXPORT ThumbCreator *new_creator()
+    Q_DECL_EXPORT ThumbCreator *new_creator()
     {
         return new GSCreator;
     }
